@@ -177,9 +177,9 @@ def load_ex5():
 
 
 madcat_collector = run_madcat(Data(df=df, target_column='target'),
-                              is_feature_stats=False,
+                              is_feature_stats=True,
                               is_pre_model=True,
-                              is_model_training=False,
+                              is_model_training=True,
                               model_run=ModelRun(n_models=3),
-                              is_post_model=False, is_model_weaknesses=False
+                              is_post_model=True, is_model_weaknesses=True
                               )
